@@ -57,7 +57,7 @@ beamer_presentation <- function(toc = FALSE,
                                 fig_width = 10,
                                 fig_height = 7,
                                 fig_crop = TRUE,
-                                fig_caption = FALSE,
+                                fig_caption = TRUE,
                                 dev = 'pdf',
                                 theme = "default",
                                 colortheme = "default",
