@@ -24,6 +24,7 @@ html_dependency_jquery <- function()  {
 #' @rdname html-dependencies
 #' @export
 html_dependency_bootstrap <- function(theme) {
+  if (identical(theme, "default")) theme <- "bootstrap"
   htmlDependency(name = "bootstrap",
                  version = "3.3.5",
                  rmarkdown_system_file("rmd/h/bootstrap-3.3.5"),
@@ -60,9 +61,83 @@ html_dependency_tocify <- function() {
 }
 
 
-# flattens an arbitrarily nested list and returns all of the html_dependency
+# create an html_dependency for font awesome
+#' @rdname html-dependencies
+#' @export
+html_dependency_font_awesome <- function() {
+  htmlDependency(
+    "font-awesome",
+    "4.5.0",
+    src = rmarkdown_system_file("rmd/h/font-awesome-4.5.0"),
+    stylesheet = "css/font-awesome.min.css"
+  )
+}
+
+# create an html_dependency for ionicons
+#' @rdname html-dependencies
+#' @export
+html_dependency_ionicons <- function() {
+  htmlDependency(
+    "ionicons",
+    "2.0.1",
+    src = rmarkdown_system_file("rmd/h/ionicons-2.0.1"),
+    stylesheet = "css/ionicons.min.css"
+  )
+}
+
+# analyze navbar html source for icon dependencies
+navbar_icon_dependencies <- function(navbar) {
+
+  # read the navbar source
+  source <- readLines(navbar)
+
+  # find icon references
+  res <- regexec('<span class="(fa fa|ion ion)-', source)
+  matches <- regmatches(source, res)
+  libs <- c()
+  for (match in matches) {
+    if (length(match) > 0)
+      libs <- c(libs, match[[2]])
+  }
+  libs <- unique(libs)
+
+  # return their dependencies
+  html_dependencies_fonts("fa fa" %in% libs, "ion ion" %in% libs)
+}
+
+
+# utilty function to return a list of font dependencies based
+# whether we are including font_awesome and/or iconicons
+html_dependencies_fonts <- function(font_awesome, ionicons) {
+  deps <- list()
+  if (font_awesome)
+    deps <- append(deps, list(html_dependency_font_awesome()))
+  if (ionicons)
+    deps <- append(deps, list(html_dependency_ionicons()))
+  deps
+}
+
+# local implementation of knit_meta_add until we can depend on a later
+# version of knitr
+knit_meta_add = function(meta, label = '') {
+  # if (packageVersion("knitr") >= "1.12.20") {
+  #   knitr::knit_meta_add(meta, label)
+  # } else {
+  knitrNamespace <- asNamespace("knitr")
+  knitEnv <- get(".knitEnv", envir = knitrNamespace)
+  if (length(meta)) {
+    meta_id = attr(knitEnv$meta, 'knit_meta_id')
+    knitEnv$meta <- c(knitEnv$meta, meta)
+    attr(knitEnv$meta, "knit_meta_id") = c(meta_id, rep(label, length(meta)))
+  }
+  knitEnv$meta
+  # }
+}
+
+
+# flattens an arbitrarily nested list and returns all of the dependency
 # objects it contains
-flatten_html_dependencies <- function(knit_meta) {
+flatten_dependencies <- function(knit_meta, test) {
 
   all_dependencies <- list()
 
@@ -71,10 +146,9 @@ flatten_html_dependencies <- function(knit_meta) {
   # a list of dependencies we recurse on lists that aren't named
   for (dep in knit_meta) {
     if (is.null(names(dep)) && is.list(dep)) {
-      inner_dependencies <- flatten_html_dependencies(dep)
+      inner_dependencies <- flatten_dependencies(dep, test)
       all_dependencies <- append(all_dependencies, inner_dependencies)
-    }
-    else if (is_html_dependency(dep)) {
+    } else if (test(dep)) {
       all_dependencies[[length(all_dependencies) + 1]] <- dep
     }
   }
@@ -82,6 +156,10 @@ flatten_html_dependencies <- function(knit_meta) {
   all_dependencies
 }
 
+flatten_html_dependencies <- function(knit_meta) {
+  flatten_dependencies(knit_meta, is_html_dependency)
+}
+
 # consolidate dependencies (use latest versions and remove duplicates). this
 # routine is the default implementation for version dependency resolution;
 # formats may specify their own.
@@ -144,25 +222,26 @@ validate_html_dependency <- function(list) {
   list
 }
 
-# check if the passed knit_meta has any html dependencies
-has_html_dependencies <- function(knit_meta) {
+# check if the passed knit_meta has any (e.g. html/latex) dependencies
+has_dependencies <- function(knit_meta, class) {
 
-  if (inherits(knit_meta, "html_dependency"))
+  if (inherits(knit_meta, class))
     return(TRUE)
 
-  else if (is.list(knit_meta)) {
+  if (is.list(knit_meta)) {
     for (dep in knit_meta) {
       if (is.null(names(dep))) {
-        if (has_html_dependencies(dep))
+        if (has_dependencies(dep, class))
           return(TRUE)
       } else {
-        if (inherits(dep, "html_dependency"))
+        if (inherits(dep, class))
           return(TRUE)
       }
     }
-
-    FALSE
-  } else {
-    FALSE
   }
+  FALSE
+}
+
+has_html_dependencies <- function(knit_meta) {
+  has_dependencies(knit_meta, "html_dependency")
 }
