@@ -22,8 +22,8 @@
 html_fragment <- function(number_sections = FALSE,
                           fig_width = 7,
                           fig_height = 5,
-                          fig_retina = if (!fig_caption) 2,
-                          fig_caption = FALSE,
+                          fig_retina = 2,
+                          fig_caption = TRUE,
                           dev = 'png',
                           smart = TRUE,
                           mathjax = TRUE,
