@@ -35,7 +35,7 @@ html_vignette <- function(fig_width = 3,
   html_document(fig_width = fig_width,
                 fig_height = fig_height,
                 dev = dev,
-                fig_retina = FALSE,
+                fig_retina = NULL,
                 css = css,
                 theme = NULL,
                 highlight = "pygments",
