@@ -43,8 +43,8 @@ slidy_presentation <- function(incremental = FALSE,
                                font_adjustment = 0,
                                fig_width = 8,
                                fig_height = 6,
-                               fig_retina = if (!fig_caption) 2,
-                               fig_caption = FALSE,
+                               fig_retina = 2,
+                               fig_caption = TRUE,
                                dev = 'png',
                                smart = TRUE,
                                self_contained = TRUE,
