@@ -43,7 +43,7 @@ word_document <- function(toc = FALSE,
                           toc_depth = 3,
                           fig_width = 5,
                           fig_height = 4,
-                          fig_caption = FALSE,
+                          fig_caption = TRUE,
                           highlight = "default",
                           reference_docx = "default",
                           keep_md = FALSE,
