@@ -91,6 +91,10 @@ function LineBreak()
   return "<br/>"
 end
 
+function SoftBreak()
+  return " "
+end
+
 function Emph(s)
   return "<em>" .. s .. "</em>"
 end
@@ -293,6 +297,7 @@ function CodeBlock(s, attr)
   local code = escape(s)
   code_sub = code:gsub("[ \t]*[#/]+[ \t]*&lt;b&gt;[ \t]*\n", "<b>")
   code = code_sub:gsub("[ \t]*[#/]+[ \t]*&lt;/b&gt;[ \t]*\n", "</b>")
+  code = code:gsub("[ \t]*[#/]+[ \t]*&lt;/b&gt;[ \t]*$", "</b>")
 
   return "<pre " .. class_attrib .. ">" .. code .. "</pre>"
 end
